summaryrefslogtreecommitdiff
path: root/firmware/lib/vboot_ui.c
diff options
context:
space:
mode:
Diffstat (limited to 'firmware/lib/vboot_ui.c')
-rw-r--r--firmware/lib/vboot_ui.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/firmware/lib/vboot_ui.c b/firmware/lib/vboot_ui.c
index bcfd2008..6e9e5169 100644
--- a/firmware/lib/vboot_ui.c
+++ b/firmware/lib/vboot_ui.c
@@ -211,7 +211,7 @@ static vb2_error_t vb2_altfw_ui(struct vb2_context *ctx)
* This will not return if successful. Drop out to
* developer mode on failure.
*/
- vb2_run_altfw(ctx, key - '0');
+ vb2_try_altfw(ctx, 1, key - '0');
active = 0;
break;
default:
@@ -476,7 +476,7 @@ static vb2_error_t vb2_diagnostics_ui(struct vb2_context *ctx)
/*
* The following helps avoid use of the TPM after
* it's disabled (e.g., when vb2_run_altfw() calls
* secdata_kernel_lock() ).
*/
@@ -488,7 +488,7 @@ static vb2_error_t vb2_diagnostics_ui(struct vb2_context *ctx)
VB2_DEBUG("Failed to disable TPM\n");
vb2api_fail(ctx, VB2_RECOVERY_TPM_DISABLE_FAILED, 0);
} else {
- vb2_run_altfw(ctx, VB_ALTFW_DIAGNOSTIC);
+ vb2_try_altfw(ctx, 1, VB_ALTFW_DIAGNOSTIC);
VB2_DEBUG("Diagnostic failed to run\n");
/*
* Assuming failure was due to bad hash, though
@@ -742,7 +742,7 @@ static vb2_error_t vb2_developer_ui(struct vb2_context *ctx)
VB2_DEBUG("VbBootDeveloper() - "
"user pressed key '%c': Boot alternative "
"firmware\n", key);
- vb2_try_alt_fw(ctx, allow_legacy, key - '0');
+ vb2_try_altfw(ctx, allow_legacy, key - '0');
break;
default:
VB2_DEBUG("VbBootDeveloper() - pressed key %#x\n", key);
@@ -758,7 +758,7 @@ static vb2_error_t vb2_developer_ui(struct vb2_context *ctx)
/* If defaulting to legacy boot, try that unless Ctrl+D was pressed */
if (use_legacy && !ctrl_d_pressed) {
VB2_DEBUG("VbBootDeveloper() - defaulting to legacy\n");
- vb2_try_alt_fw(ctx, allow_legacy, 0);
+ vb2_try_altfw(ctx, allow_legacy, 0);
}
if ((use_usb && !ctrl_d_pressed) && allow_usb) {
@@ -476,7 +476,7 @@ static vb2_error_t vb2_diagnostics_ui(struct vb2_context *ctx)
/*
* The following helps avoid use of the TPM after
- * it's disabled (e.g., when vb2_run_altfw() calls
+ * it's disabled (e.g., when vb2_try_altfw() calls
* secdata_kernel_lock() ).
*/